@@ -187,6 +187,7 @@ class mPrefs:
 class mCalendar:
         """This is the mCalendar Application"""
         def createTable(self):
+          global VERSION
           try:
             self.dbcur.execute('CREATE TABLE events (uuid TEXT PRIMARY KEY, start DATETIME, end DATETIME, description TEXT, repeat INTEGER, repeatvalue INTEGER, frequency TEXT,until DATETIME, lastup DATETIME, googleid TEXT, byday TEXT, alarm INTEGER, alarm_value INTEGER, alarm_id INTEGER, cal_id TEXT)')
             self.db.commit()
@@ -264,6 +265,7 @@ class mCalendar:
 
         def __init__(self,app,background=False):
                 self.background=background
+                global VERSION
                 try:
                   if HILDON_SUPPORT:
                     db_path='/home/user/.mPIM/mcalendar.db'
@@ -281,6 +283,27 @@ class mCalendar:
                   self.db = sqlite3.connect(db_path)
                   self.dbcur = self.db.cursor()
 
+                try:                                  
+                  #quick fix
+                  self.dbcur.execute('CREATE TABLE cal (id TEXT PRIMARY KEY,access_level TEXT, color TEXT, last_update TEXT);')
+                  self.db.commit()
+                  self.dbcur.execute('ALTER TABLE events ADD cal_id TEXT')
+                  self.db.commit()
+                  self.dbcur.execute('CREATE TABLE cal (id TEXT PRIMARY KEY,access_level TEXT, color TEXT, last_update TEXT);')
+                  self.db.commit()
+                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("popup_alarm",?);',['False'])
+                  self.db.commit()
+                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("auto_sync",?);',['False'])
+                  self.db.commit()
+                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("use_google_color",?);',['True'])
+                  self.db.commit()
+                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("auto_sync_id",?);',[''])
+                  self.db.commit()
+                  self.dbcur.execute('INSERT INTO prefs (id,content) VALUES ("display_day",?);',['True'])
+                  self.db.commit()
+                except:
+                  pass
+
                 try:
                   self.dbcur.execute('SELECT content FROM prefs WHERE id = "VERSION";')
                   v = self.dbcur.fetchall()
@@ -355,7 +378,6 @@ class mCalendar:
                 self.window.connect("key-press-event", self.on_key_press)
                 self.window.connect("window-state-event", self.on_window_state_change)  
                 self.window_in_fullscreen = False #The window isn't in full screen mode initially.
-                
 
 #                self.window.set_icon(gtk.gdk.pixbuf_new_from_file('/usr/share/pixmaps/mcalendar26.png'))
                 #set a win background
@@ -382,7 +404,7 @@ class mCalendar:
                   self.app.add_window(self.window)
                   if (background == False):
                     self.window.show_all()
-                    
+
 #                self.window.set_icon_from_file('/usr/share/pixmaps/mcalendar26.png')
 
                 #Create our dictionay and connect it
@@ -444,6 +466,8 @@ class mCalendar:
 
         def get_fg_color(self,cal_id):
           global USE_GOOGLE_COLOR
+          if cal_id == None:
+            cal_id = 'default'
 
           if USE_GOOGLE_COLOR == False:
             return "#000000"
@@ -475,10 +499,6 @@ class mCalendar:
               start_format = ALLDAY_VIEW_FORMAT
             end_format = ''
 
-#            if self.last_date_list != start_datetime.date():
-#              self.last_date_list = start_datetime.date()
-#              self.data.store.append(("","",start_datetime.strftime("%x"),"noteditable","","","#FFFFFF","#CC0000"))
-
           if (start_datetime.date()==end_datetime.date()) or (self.current_view == 0):
             if (start_format==DAY_VIEW_FORMAT) and (end_format==DAY_VIEW_FORMAT):
               ds = start_datetime.strftime(start_format)+'\n'+end_datetime.strftime(end_format)
